#! /bin/zsh

# Jonathan Frech, 17th and 18th of April 2020
# Meant to be installed in the following way.
#     % curl --silent https://www.jfrech.com/jblog/post227/install.zsh | zsh

jprompt="$HOME/.jprompt"

[ -d "$jprompt" ] && echo "Directory '$jprompt' already exists. Aborting." \
    && exit 1

[ -z "$(command -v curl)" ] && echo "Please install 'curl'." && exit 1
[ -z "$(command -v make)" ] && echo "Please install 'make'." && exit 1
[ -z "$(command -v gcc)" ] && echo "Please install 'gcc'." && exit 1

mkdir -p "$jprompt"
tar -xf =(curl --fail --silent \
    "https://www.jfrech.com/jblog/post227/.jprompt.tar.gz") -C "$jprompt"
cd "$jprompt"
make > /dev/null
chmod +x "$jprompt/jprompt"

[ -z "$ZDOTDIR" ] && zshrc="$HOME/.zshrc"
[ -n "$ZDOTDIR" ] && zshrc="$ZDOTDIR/.zshrc"

load_jprompt1="setopt PROMPT_SUBST"
load_jprompt2="export PROMPT='\$($jprompt/jprompt) %M@%n %5~ %# %E'"

printf "Append the lines\n    "
echo $load_jprompt1
printf "    "
echo $load_jprompt2
printf "to '$zshrc'? [Y/n] "
read -q confirmation
[ "$confirmation" = 'n' ] && return
printf "\n"

echo "$load_jprompt1" >> "$zshrc"
echo "$load_jprompt2" >> "$zshrc"
printf "Please reload '$zshrc' -- for example via 'exec zsh' -- "
echo "for the change to take effect."
